==> guikachu-1.3.6.tar.gz: guikachu-1.3.6/src/io/xml/res-bitmap.cc <==
//$Id: res-bitmap.cc,v 1.5 2003/12/24 14:14:05 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#include "io/xml/res-bitmap.h"

#include "io/storage-processor.h"
#include "io/storage-node-handlers.h"

using namespace Guikachu::IO::XML;

BitmapIOAdaptor::BitmapIOAdaptor (Resources::Bitmap *res_):
    res (res_)
{
}

void BitmapIOAdaptor::load (const StorageNode &node)
{
    std::string type_str = node.get_prop_string ("type");
    Resources::Bitmap::BitmapType type = Resources::Bitmap::TYPE_GREY_16;
    
    if (type_str == "mono")
        type = Resources::Bitmap::TYPE_MONO;
    else if (type_str == "grey_4")
        type = Resources::Bitmap::TYPE_GREY_4;
    else if (type_str == "grey_16")
        type = Resources::Bitmap::TYPE_GREY_16;
    else if (type_str == "color_16")
        type = Resources::Bitmap::TYPE_COLOR_16;
    else if (type_str == "color_256")
        type = Resources::Bitmap::TYPE_COLOR_256;

    res->bitmap_type = type;
    
    // Create dummy property
    VSignal sig;
    Property<std::string> image_data_base64_prop (sig);
    
    StorageProcessor processor;
    processor.add_handler ("image_data", new StorageNodeHandlers::StringContents (image_data_base64_prop));

    processor.run (node);

    Magick::Blob blob;
    blob.base64 (image_data_base64_prop);
    res->set_image (blob);
}

void BitmapIOAdaptor::save (StorageNode &node)
{
    std::string type_str;
    
    switch (res->bitmap_type ())
    {
    case Resources::Bitmap::TYPE_MONO:
        type_str = "mono";
        break;    
    case Resources::Bitmap::TYPE_GREY_4:
        type_str = "grey_4";
        break;
    case Resources::Bitmap::TYPE_GREY_16:
        type_str = "grey_16";
        break;
    case Resources::Bitmap::TYPE_COLOR_16:
        type_str = "color_16";
        break;
    case Resources::Bitmap::TYPE_COLOR_256:
        type_str = "color_256";
        break;
    }

    node.set_prop ("type", type_str);
    
    const Magick::Image &image = res->get_image ();
    Magick::Blob blob;
    
    // Magick::Image::write is not a const method
    const_cast<Magick::Image&>(image).write (&blob);
    
    node.add_node ("image_data", blob.base64 ()).set_prop ("encoding", "base64");
}

==> guikachu-1.3.7.tar.gz: guikachu-1.3.7/src/io/xml/res-bitmap.cc <==
//$Id: res-bitmap.cc,v 1.6 2004/01/20 20:07:32 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#include "io/xml/res-bitmap.h"

#include "io/storage-processor.h"
#include "io/storage-node-handlers.h"

using namespace Guikachu::IO::XML;

BitmapIOAdaptor::BitmapIOAdaptor (Resources::Bitmap *res_):
    res (res_)
{
}

void BitmapIOAdaptor::load (const StorageNode &node)
{
    std::string type_str = node.get_prop_string ("type");
    Resources::Bitmap::BitmapType type = Resources::Bitmap::TYPE_GREY_16;
    
    if (type_str == "mono")
        type = Resources::Bitmap::TYPE_MONO;
    else if (type_str == "grey_4")
        type = Resources::Bitmap::TYPE_GREY_4;
    else if (type_str == "grey_16")
        type = Resources::Bitmap::TYPE_GREY_16;
    else if (type_str == "color_16")
        type = Resources::Bitmap::TYPE_COLOR_16;
    else if (type_str == "color_256")
        type = Resources::Bitmap::TYPE_COLOR_256;
    else if (type_str == "color_16k")
	type = Resources::Bitmap::TYPE_COLOR_16K;

    res->bitmap_type = type;
    
    // Create dummy property
    VSignal sig;
    Property<std::string> image_data_base64_prop (sig);
    
    StorageProcessor processor;
    processor.add_handler ("image_data", new StorageNodeHandlers::StringContents (image_data_base64_prop));

    processor.run (node);

    Magick::Blob blob;
    blob.base64 (image_data_base64_prop);
    res->set_image (blob);
}

void BitmapIOAdaptor::save (StorageNode &node)
{
    std::string type_str;
    
    switch (res->bitmap_type ())
    {
    case Resources::Bitmap::TYPE_MONO:
        type_str = "mono";
        break;    
    case Resources::Bitmap::TYPE_GREY_4:
        type_str = "grey_4";
        break;
    case Resources::Bitmap::TYPE_GREY_16:
        type_str = "grey_16";
        break;
    case Resources::Bitmap::TYPE_COLOR_16:
        type_str = "color_16";
        break;
    case Resources::Bitmap::TYPE_COLOR_256:
        type_str = "color_256";
        break;
    case Resources::Bitmap::TYPE_COLOR_16K:
	type_str = "color_16k";
	break;
    }

    node.set_prop ("type", type_str);
    
    const Magick::Image &image = res->get_image ();
    Magick::Blob blob;
    
    // Magick::Image::write is not a const method
    const_cast<Magick::Image&>(image).write (&blob);
    
    node.add_node ("image_data", blob.base64 ()).set_prop ("encoding", "base64");
}
